; hdhrview.au3 - An AutoIt script that needs to be compiled
;
; usage:  hdhrview $channel
;
;			channel = 0 will kill the app
;			channel <> 0 will start the app and set to the desired channel, or if already running just set the channel
;
;			NOTE: If the channel is the same as the previously set channel then the channel will NOT be sent again
;
; This AutoIT script will start the HDHomeRun Viewer app and then set the desired channel.
; If the channel number is the same then it will not pass on the channel, as the app will change to the DVR screen.
; If the channel number is ZERO then it will kill the Viewer app.

#include <Array.au3>
#include <File.au3>
#include <MsgBoxConstants.au3>

; appname is the batch file or exe that starts the HDHRview app. Not the same as the process name.
; NOTE: Edit the filepath as appropriate

Global $filepath = "C:\Scripts\"
Global $chanfile = "prevchan.txt"
Local $appname = "startHDHRview.bat"
Global $channel
Global $prevchan
Global $keydelay = 400
Local $PID
Global $channel
Local $procname = "HDHomeRunView.exe"
Global $hFileOpen
Local $startdelay = 10000
Global $filename

Opt("SendKeyDelay", 200) ;5 milliseconds
Opt("SendKeyDownDelay", 50) ;1 millisecond

; if desired Channel is ZERO then look for HDHRviewer and terminate

$channel = $CmdLine[1]
If $channel == 0 Then
   $PID = ProcessExists($procname)
   ProcessClose($PID)
   Exit
EndIf

; read previous channel from file

$filename = $filepath & $chanfile
ChanFileProc($FO_READ)


; Start HDHomeRun app and then wait for it

$filename = $filepath & $appname
ShellExecute($filename)
Sleep($startdelay)
WinActivate("HDHomeRun")

; If previous channel is same as requested channel then do nothing else

If $prevchan = $channel Then
   Exit
EndIf

; We have a new channel to tune so first save the channel in the file, then use simulated keystrokes to set the channel

$filename = $filepath & $chanfile
ChanFileProc($FO_OVERWRITE)
SetChannel()

Exit

Func SetChannel()

; Sequence is ENTER, zero, channel number, zero, Backspace, ENTER
; May seem odd but it works, otherwise the number may not be entered

   ;Send ENTER
   Send("{ENTER}")
   Sleep($keydelay)

   ;Send zero
   Send(0)
   Sleep($keydelay)

   ;Send the channel Number
   Send($channel)
   Sleep($keydelay)

   ;Send zero
   Send(0)
   Sleep($keydelay)

   ;Send Backspace
   Send("{BACKSPACE}")
   Sleep($keydelay)

   ;Send ENTER
   Send("{ENTER}")

EndFunc

Func ChanFileProc(Const $mode)

   ; Open the file for reading or writing depending on $val

    $hFileOpen = FileOpen($filename, $mode)
    If $hFileOpen = -1 Then
        MsgBox($MB_SYSTEMMODAL, "", "An error occurred when opening the file.")
        Return False
    EndIf

   ; Read or write the FileChangeDir

   If $mode = $FO_READ Then
	  $prevchan = FileReadLine($hFileOpen,1)
   ElseIf $mode = $FO_OVERWRITE Then
	  FileWriteLine($hFileOpen,$channel)
   EndIf


; Close the file
   FileClose($hFileOpen)

EndFunc